==> likeit-2.0.0.tar.gz: likeit/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Maintainers


INTRODUCTION
------------

This module provides Likeit entity and extra field to like/unlike (via Ajax)
or view likes count of the entities. Provides additional user permissions.
Supports Views integration. You can subscribe to the like/unlike event through
registering event subscribers, see
https://api.drupal.org/api/drupal/core%21core.api.php/group/events/8.3.x

 * For a full description of the module, visit the project page:
   https://www.drupal.org/project/likeit

 * To submit bug reports and feature suggestions, or to track changes:
   https://www.drupal.org/project/issues/likeit


REQUIREMENTS
------------

This module requires the following outside of Drupal core:

 * Extrafield Views Integration -
   https://www.drupal.org/project/extrafield_views_integration


INSTALLATION
------------

 * Install the Extra Field Settings Provider module as you would normally
   install a contributed Drupal module. Visit
   https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

The module has configuration page Configuration > User Interface > Like It!.
There you can select entities to provide extra field and set other configs for
the module.


MAINTAINERS
-----------

 * Andrew Tsiupiakh (andrew_tspkh) - https://www.drupal.org/user/3302731

Supporting organizations:

 * Drupal Ukraine Community - https://www.drupal.org/drupal-ukraine-community

==> likeit-2.1.0.tar.gz: likeit/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Maintainers


INTRODUCTION
------------

This module provides Likeit entity and extra field to like/unlike (via Ajax)
or view likes count of the entities. Provides additional user permissions.
Supports Views integration. You can subscribe to the like/unlike event through
registering event subscribers, see
https://api.drupal.org/api/drupal/core%21core.api.php/group/events/8.3.x

 * For a full description of the module, visit the project page:
   https://www.drupal.org/project/likeit

 * To submit bug reports and feature suggestions, or to track changes:
   https://www.drupal.org/project/issues/likeit


REQUIREMENTS
------------

This module requires the following outside of Drupal core:

 * Extrafield Views Integration -
   https://www.drupal.org/project/extrafield_views_integration


INSTALLATION
------------

 * Install the Extra Field Settings Provider module as you would normally
   install a contributed Drupal module. Visit
   https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

 * The module has configuration page Configuration > User Interface > Like It!.
   There you can select entities to provide extra field and set other configs
   for the module.
 * 'Likeit' fields are disabled by default in entity view displays.



MAINTAINERS
-----------

 * Andrew Tsiupiakh (andrew_tspkh) - https://www.drupal.org/user/3302731

Supporting organizations:

 * Drupal Ukraine Community - https://www.drupal.org/drupal-ukraine-community
